@@ -1,4 +1,4 @@
-// Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
+// Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
 use std::fmt;
 use std::sync::Arc;
@@ -118,7 +118,7 @@ impl ParsedSource {
       .inner
       .comments
       .get_leading(self.inner.program.span().lo)
-      .unwrap_or_else(Vec::new)
+      .unwrap_or_default()
   }
 
   /// Gets the tokens found in the source file.
